===========
``rpds.py``
===========

|PyPI| |Pythons| |CI|

.. |PyPI| image:: https://img.shields.io/pypi/v/rpds-py.svg
  :alt: PyPI version
  :target: https://pypi.org/project/rpds-py/

.. |Pythons| image:: https://img.shields.io/pypi/pyversions/rpds-py.svg
  :alt: Supported Python versions
  :target: https://pypi.org/project/rpds-py/

.. |CI| image:: https://github.com/Julian/rpds.py/workflows/CI/badge.svg
  :alt: Build status
  :target: https://github.com/Julian/rpds.py/actions?query=workflow%3ACI


Python bindings to the Rust ``rpds`` crate.
